@@ -40,6 +40,11 @@ class Batch(object):
         self.function_meta = {}
         self.documents = {}
 
+        # set specific options
+        if self.config.get('opts', False):
+            self.config['reset'] = self.config['opts'].reset
+            self.config['forcedelete'] = self.config['opts'].forcedelete
+
     def setup_logging(self):
         self.logger = logging.getLogger(name="precipy")
 
@@ -101,7 +106,7 @@ class Batch(object):
         for storage in self.storages:
             storage.init(self)
             storage.connect()
-            if self.config['opts'].reset:
+            if self.config.get('reset'):
                 self.logger.debug("resetting cache for %r" % storage)
                 storage.reset_cache()
 
@@ -226,16 +231,17 @@ class Batch(object):
             af.load_metadata()
 
         if not af.metadata_path_exists():
-            self.logger.debug("    not found")
+            self.logger.debug("    not found, checking remote storages...")
             if af.download_from_storages(af.metadata_cache_filepath()):
                 af.load_metadata()
                 for sf in af.files.values():
+                    self.logger.debug("    downloading supplemental file %s" % sf.canonical_filename)
                     filepath = af.supplemental_file_cache_filepath(sf.canonical_filename)
                     if not af.download_from_storages(filepath):
                         raise Exception("couldn't download storage for %s" % filepath)
 
         if not af.metadata_path_exists():
-            self.logger.debug("cached metadata not found, running the function")
+            self.logger.debug("cached metadata not found locally or remotely, running the function")
             af.run_function()
             af.is_populated = True
             af.from_cache = False
