@@ -2,6 +2,7 @@ class Storage(object):
     def init(self, batch):
         self.cache_bucket_name = batch.cache_bucket_name
         self.output_bucket_name = batch.output_bucket_name
+        self.forcedelete = batch.config.get('forcedelete')
         self.logger = batch.logger
 
     def __repr__(self):
@@ -31,14 +32,14 @@ class Storage(object):
         """
         pass
 
-    def download_cache(self, cache_filepath):
+    def download_cache(self, local_cache_filepath):
         """
         Download the file from storage to local file system at cache_filepath 
 
         Should return true if sucessful, false if file does not exist remotely
         """
-        cache_filename = cache_filepath.name
-        return self._download_cache(cache_filename, cache_filepath)
+        cache_filename = local_cache_filepath.name
+        return self._download_cache(cache_filename, local_cache_filepath)
 
     def _download_cache(self, cache_filename, cache_filepath):
         """
@@ -76,19 +77,42 @@ class Storage(object):
 
 
 class GoogleCloudStorage(Storage):
+    SAFETY_FILENAME = "_precipy"
+
     def find_or_create_bucket(self, bucket_name):
         import google.api_core.exceptions
         try:
             bucket = self.storage_client.get_bucket(bucket_name)
         except google.api_core.exceptions.NotFound:
             self.logger.debug("creating bucket %s" % bucket_name)
-            bucket = self.storage_client.create_bucket(bucket_name)
-
-        #bucket.make_public(recursive=True, future=True)
+            bucket = self.storage_client.create_public_bucket(bucket_name)
         return bucket
 
+    def create_safety_file(self, bucket):
+        self.logger.debug("creating safety file %s" % self.SAFETY_FILENAME)
+        blob = bucket.blob(self.SAFETY_FILENAME)
+        blob.upload_from_string("""Created by precipy.
+        Bucket and all contents may be deleted by a subsequent precipy reset.
+        Copy this bucket before publication to protect from deletion.
+        Deleting this file will provide limited protection against accidental deletion.
+        """)
+        self.logger.debug(blob.public_url)
+
+    def assert_safe_to_delete(self, bucket):
+        blob = bucket.blob(self.SAFETY_FILENAME)
+        msg = """
+        No %s file found in %s
+        To ensure we do not accidentally delete important data,
+        you must create this file in this bucket or delete this bucket manually.
+        OR if you are sure it is okay to delete this bucket, pass the -forcedelete option
+             (you should only need to pass this once, then remove it as safety file will have been created)
+        """ % (self.SAFETY_FILENAME, bucket.name)
+        assert blob.exists(), msg
+
     def delete_cache_bucket(self):
         try:
+            if not self.forcedelete:
+                self.assert_safe_to_delete(self.cache_storage_bucket)
             self.cache_storage_bucket.delete(force=True)
         except ValueError:
             blobs = self.cache_storage_bucket.list_blobs()
@@ -98,6 +122,8 @@ class GoogleCloudStorage(Storage):
 
     def delete_output_bucket(self):
         try:
+            if not self.forcedelete:
+                self.assert_safe_to_delete(self.output_storage_bucket)
             self.output_storage_bucket.delete(force=True)
         except ValueError:
             blobs = self.output_storage_bucket.list_blobs()
@@ -108,6 +134,7 @@ class GoogleCloudStorage(Storage):
     def create_public_bucket(self, name):
         bucket = self.storage_client.create_bucket(name)
         bucket.make_public(recursive=True, future=True)
+        self.create_safety_file(bucket)
         return bucket
 
     def connect(self):
@@ -122,11 +149,12 @@ class GoogleCloudStorage(Storage):
         blob.upload_from_filename(str(cache_filepath))
         return blob.public_url
 
-    def _download_cache(self, cache_filename, cache_filepath):
+    def _download_cache(self, cache_filename, local_cache_filepath):
+        self.logger.debug("  looking for cached file %s" % cache_filename)
         blob = self.cache_storage_bucket.blob(cache_filename)
         if blob.exists():
-            self.logger.debug("  blob exists, downloading from %s to %s" % (self.cache_bucket_name, cache_filepath))
-            blob.download_to_filename(cache_filepath)
+            self.logger.debug("  blob exists, downloading from %s to %s" % (self.cache_bucket_name, local_cache_filepath))
+            blob.download_to_filename(local_cache_filepath)
             return True
         else:
             return False
