@@ -8,7 +8,7 @@ config = {
     "filters" : [["markdown", "html"]],
     # Sources for data prep & asset gen (plots, json data)
     'analytics' : [
-        ['wavy_line_plot', {'a' : 7, 'b' : 4}]
+        ['wavy_line_plot', {'a' : 3, 'b' : 4}]
         ]
     }
 
@@ -31,3 +31,14 @@ def test_batch_integration():
     print(batch.documents)
 
     assert batch.template_filenames == ["%s.md" % batch.h]
+
+def test_range_environments():
+    config['ranges'] = { 'a' : [1,2,3], 'b' : { "start" : 1, "stop" : 9, "step" : 2 }}
+    batch = Batch(config)
+    envs = batch.range_environments()
+    print(envs)
+
+def test_range_analytics():
+    config['ranges'] = { 'a' : [1,2,3], 'b' : { "start" : 1, "stop" : 9, "step" : 2 }}
+    batch = Batch(config)
+    batch.generate_analytics([tests.analytics])
